bayespy.inference.vmp.nodes.gaussian.GaussianToGaussianGamma.move_plates
========================================================================

.. currentmodule:: bayespy.inference.vmp.nodes.gaussian

.. automethod:: GaussianToGaussianGamma.move_plates